require "core"
require "dbc_file"

class WorldMapAreaFile < DBCFile
  # Field Info
  # 0  ID
  # 1  MapID
  # 2  area id
  # 3  Name
  # 4  y1
  # 5  y2
  # 6  x1
  # 7  x2
  # 8  virtualID
  # 9  dungone map
  # 10 Phase?
  # 11 Unkown 4.0.0
  def initialize(path)
      begin
        super("#{path}#{File::SEPARATOR}WorldMapArea.dbc","iiisFFFFIIIIII")
      rescue Exception => e
        super("#{path}#{File::SEPARATOR}WorldMapArea.dbc","iiisFFFFIIII")      
      end
      @zoneInfo = Hash.new
  end
end

class DungeonMapFile < DBCFile
  # Field Info
  # 0 subID
  # 1 worldmapID
  # 2 floor
  # 3 y1
  # 4 y2
  # 5 x1
  # 6 x2
  # 7 Unknown
  def initialize(path)
      super("#{path}#{File::SEPARATOR}DungeonMap.dbc","iiiFFFFI")
  end
end

class WorldMapContinentFile < DBCFile
  # Field Info
  # 0  ID
  # 1  MapID
  # 2  Unknown
  # 3  Unknown
  # 4  Unknown
  # 5  Unknown
  # 6  Unknown
  # 7  Unknown
  # 8  Unknown
  # 9  y1
  # 10 y2
  # 11 x1
  # 12 x2
  def initialize(path)
    super("#{path}#{File::SEPARATOR}WorldMapContinent.dbc","iIiiiiffffffff")
  end
end

class WorldMapTransformFile < DBCFile
  def initialize(path)
    super("#{path}#{File::SEPARATOR}WorldMapTransforms.dbc","iiffffiffiii")
  end
end

class MapFile < DBCFile
  # Field info
  # 0  MapID
  # 1  internalname
  # 2  map_type
  # 3  mapFlags
  # 4 NEW FIELD HERE UNKNOW seems to go 1,2,3 
  # 5  isPvP 0 or 1 for battlegrounds (not arenas)
  # 6  name
  # 7  linked_zone  common zone for instance and continent map
  # 8  hordeIntro
  # 9  allianceIntro
  # 10  multimap_id; // index in LoadingScreens.dbc
  # 11 BattlefieldMapIconScale
  # 12 ghost_entrance_map map_id of entrance map in ghost mode (continent always and in most cases = normal entrance)
  # 13 ghost_entrance_x entrance x coordinate in ghost mode (in most cases = normal entrance)
  # 14 ghost_entrance_y entrance y coordinate in ghost mode (in most cases = normal entrance)
  # 15 timeOfDayOverride
  # 16  expansion
  # 17 unkTime
  # 18 maxPlayers
  # 19 unk400 new 4.0.0, mapid, related to phasing
  def initialize(path)
    if path =~ /Old/ then
      super("#{path}#{File::SEPARATOR}Map.dbc","isiiiisissifIffIIII")
    else
      begin
        super("#{path}#{File::SEPARATOR}Map.dbc","isiiiisissifIffIIIIII")
      rescue Exception => e
        super("#{path}#{File::SEPARATOR}Map.dbc","isiiiisissifIffIIII")      
      end
    end
  end
end